import type { Action } from '../types/ActionTypes';
/**
 * With the `use-download` action, a download will occur with a given Blob object as a file with the given filename.
 *
 * ```tsx
 *  <button use:download={{ blob: new Blob([]), filename: "text.txt" }} on:usedownload={() => { console.log('download');}}>Download</button>
 * ```
 * @param params - Object that contains two properties {blob: Blob, filename: string}
 * @see https://svelteui-docs.vercel.app/docs/actions/use-download
 */
export declare function download(node: HTMLElement, params: {
    blob: Blob;
    filename: string;
}): ReturnType<Action>;
